declare let kht: any;
import config from '@/assets/config';
/**
 * @description 时间格式化
 * @param date
 */
export function formatter(date: Date | string, format?: string): string {
  date = new Date(date as Date);
  const year = date.getFullYear();
  const month = date.getMonth();
  const days = date.getDate();
  const hours = date.getHours();
  const mins = date.getMinutes();
  const seconds = date.getSeconds();
  const MM = month > 8 ? month + 1 : `0${month + 1}`;
  const dd = days > 9 ? days : `0${days}`;
  const HH = hours > 9 ? hours : `0${hours}`;
  const mm = mins > 9 ? mins : `0${mins}`;
  const ss = seconds > 9 ? seconds : `0${seconds}`;
  if (format === 'yyMMddHHmmss') {
    return `${year}${MM}${dd}${HH}${mm}${ss}`;
  } else {
    // yyyy-MM-dd
    return `${year}-${MM}-${dd}`;
  }
}

/**
 * @description 脱敏通用方法
 * @param str 需要脱敏的字符串
 * @param start 开始位置
 * @param end 结束位置 比如 倒数第二位 -2
 */
export function desensitization(str: string, start: number, end: number ): string {
    const len = str.length;
    const firstStr = str.substr(0, start);
    const lastStr = str.substr(end);
    const middleStr = str.substring(start, len - Math.abs(end)).replace(/[\s\S]/ig, '*');
    const tempStr = firstStr + middleStr + lastStr;

    return tempStr;
}

/**
 * 身份证验证
 * @param value
 */
export function modIDNumberConfirm(value: any): any {
  const city: any = {
    11: '北京',
    12: '天津',
    13: '河北',
    14: '山西',
    15: '内蒙古',
    21: '辽宁',
    22: '吉林',
    23: '黑龙江 ',
    31: '上海',
    32: '江苏',
    33: '浙江',
    34: '安徽',
    35: '福建',
    36: '江西',
    37: '山东',
    41: '河南',
    42: '湖北 ',
    43: '湖南',
    44: '广东',
    45: '广西',
    46: '海南',
    50: '重庆',
    51: '四川',
    52: '贵州',
    53: '云南',
    54: '西藏 ',
    61: '陕西',
    62: '甘肃',
    63: '青海',
    64: '宁夏',
    65: '新疆',
    71: '台湾',
    81: '香港',
    82: '澳门',
    91: '国外 ',
  };
  const reg = /^\d{6}(18|19|20)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)$/i;
  if (!value || !reg.test(value)) {
    return '身份证号错误';
  } else if (!city[value.substr(0, 2)]) {
    return '身份证号错误';
  } else {
    // 18位身份证需要验证最后一位校验位
    if (value.length === 18) {
      value = value.split('');
      // ∑(ai×Wi)(mod 11)
      // 加权因子
      const factor = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2];
      // 校验位
      const parity = [1, 0, 'X', 9, 8, 7, 6, 5, 4, 3, 2];
      let sum = 0;
      let ai = 0;
      let wi = 0;
      for (let i = 0; i < 17; i++) {
        ai = value[i];
        wi = factor[i];
        sum += ai * wi;
      }
      const last = parity[sum % 11].toString();
      if (last === value[17]) {
        return '';
      } else {
        return '身份证号错误';
      }
    } else {
      return '';
    }
  }
}

/**
 * 手机号验证
 * @param value
 */
export function modPhoneConfirm(value: any): any {
  // /^(?=\d{11}$)^1(?:3\d|4[57]|5[^4\D]|7[^249\D]|8\d)\d{8}$/
  const reg = /^(?=\d{11}$)^1\d{10}$/;
  if (!value || !reg.test(value)) {
    return '请输入正确的手机号码';
  } else {
    return '';
  }
}

/**
 * 邮箱验资
 * @param value
 */
export function modEmailConfirm(value: any): any {
  const exg = /^[a-zA-Z0-9_-]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$/;
  if (!value || exg.test(value)) {
    return '';
  }
  return '请填写正确的邮箱';
}

export function modCarNoConfirm(value: string): any {
  const exg = /^[\u4e00-\u9fa5a-zA-Z0-9_]{7,8}/;
  if (!value || exg.test(value)) {
    return '';
  }
  return '请输入正确的车牌号';
}

/**
 * 身份证格式化年龄
 * @param value
 */
export function IdToBeath(value: string): string {
  if (value.length === 18) {
    return `${value.substring(6, 10)}-${value.substring(10, 12)}-${value.substring(12, 14)}`;
  } else {
    return `19${value.substring(6, 8)}-${value.substring(8, 10)}-${value.substring(10, 12)}`;
  }
}

/**
 * 身份证格式化性别
 * @description 1: 男， 2: 女
 * @param value
 */
export function IdToGender(value: string): string {
  if (value.length === 18) {
    if (Number(value.substr(16, 1)) % 2 === 1) {
      return '1';
    } else {
      return '2';
    }
  } else {
    if (Number(value.substr(14, 1)) % 2 === 1) {
      return '1';
    } else {
      return '2';
    }
  }
}

/**
 * 获取数组对应值
 * @param arr
 * @param value
 */
export function choiceArr(arr: any, value: any, valueName = 'value'): number {
  return arr.findIndex((element: any) => (element[valueName] === value));
}

/**
 * 分秒倒计时
 * @param endString 结束时间
 */
export function countTimeDate(endString: string): string {
  const end: Date = new Date(endString);
  const now: Date = new Date();
  const nowTime = now.getTime();
  const endTime = end.getTime();
  const leftTime: number = endTime - nowTime;
  if (leftTime > 0) {
    const mm = Math.floor(leftTime / 1000 / 60 % 60);
    const dd = Math.floor(leftTime / 1000 % 60);
    return `${mm > 9 ? mm : `0${mm}`}:${dd > 9 ? dd : `0${dd}`}`;
  } else {
    return '00:00';
  }
}

/**
 * 分秒倒计时
 * @param totalSecond 结束时间
 */
export function countTime(totalSecond: number): string {
  if (totalSecond > 0) {
    const mm = Math.floor(totalSecond / 1000 / 60 );
    const dd = Math.floor((totalSecond / 1000) % 60);
    return `${mm > 9 ? mm : `0${mm}`}:${dd > 9 ? dd : `0${dd}`}`;
  } else {
    return '00:00';
  }
}

/**
 * 支付方式筛选
 * @param payMethod 过滤条件
 * @param pays 前端设置所有情况
 */
export function screenPayWay(payMethod: string, pays: any[]): any[] {
  const payMethodArr = payMethod.split(',');
  const arr: any[] = [];
  pays.forEach((element) => {
    const index = payMethodArr.findIndex((payWay: string) => payWay === element.value);
    if (index >= 0) {
      arr.push(element);
    }
  });
  return arr;
}

/**
 * 计算年龄是否符合
 * @param birthday 生日
 */
export function computeAge(birthday: string): number {
  const birth = new Date(birthday);
  const birthYear = birth.getFullYear();
  const birthMonth = birth.getMonth();
  const birthDay = birth.getDate();
  const now = new Date();
  const nowYear = now.getFullYear();
  const nowMonth = now.getMonth();
  const nowDay = now.getDate();
  const ageDiff: number = nowYear - birthYear;
  const monthDiff = nowMonth - birthMonth; // 月之差
  const dayDiff = nowDay - birthDay; // 日之差
  if (ageDiff === 0) {
    return ageDiff;
  } else if (ageDiff < 0) {
    return -1;
  } else if (monthDiff < 0) {
    return ageDiff - 1;
  } else if (monthDiff > 0) {
    return ageDiff;
  } else if (dayDiff < 0) {
    return ageDiff - 1;
  } else {
    return ageDiff;
  }
}

/**
 * 第三方查询格式话
 * @description 1:男，2:女
 * @param gender 性别 0男1女
 */
export function userInfoToGender(gender: string): string {
  return gender === '0' ? '1' : '2';
}

/**
 * 获取现在开始前后多少年的时间
 * @description -10表示之前10年 10 表示之后10年
 * @param year 现在开始后多少年
 */
export function getDateAfterYear(year: number): Date {
  const now = new Date();
  const nowYear = now.getFullYear();
  const nowMonth = now.getMonth();
  const nowDate = now.getDate();
  return new Date(nowYear + year , nowMonth, nowDate);
}
/**
 * 去除首尾空格
 * @author johnbian
 */
export function trimStr(str: string): string {
  return str.replace(/^\s\s*/, '').replace(/\s\s*$/, '');
}

/**
 * 用于服务申请时 必填项检验
 * @param requireList 必填列表
 * @param needSaveDate 已填写信息
 * @param layout 页面布局字段
 * @author johnbian
 */
export function modRequireInfo(requireList: any, needSaveDate: any, layout: any): boolean {
  let allPass: boolean = false;
  if (requireList.length === 0) {
    allPass = true;
  } else {
    for (const el of requireList) {
      if (!needSaveDate[el] && layout.indexOf(el) > -1) {
        allPass = false;
        break;
      } else {
        allPass = true;
      }
    }
  }
  return allPass;
}

/**
 * 用于服务申请时 获取必填项
 * @param list 列表
 */
export function getReuireList(list: any): string[] {
  const requireList: string[] = [];
  Object.keys(list).forEach((item) => {
    if (list[item] === '1') {
      requireList.push(item);
    }
  });
  return requireList;
}

/**
 * 金额输入框进行限定
 * 只能输入数字和小数点；小数点只能有1个；第一位不能是小数点；第一位如果输入0，且第二位不是小数点，则去掉第一位的0；小数点后保留2位
 * @param num
 */
export function numberCheck(num: string) {
  let num1 = num;
  num1 = num1.replace(/[^\d.]/g, ''); // 清除"数字"和"."以外的字符
  num1 = num1.replace(/^\./g, ''); // 验证第一个字符是数字而不是
  const index = num1.indexOf('.');
  if (index > -1 && num1.slice(0, index).length > 8) {
    num1 = num1.slice(0, index);
  }
  num1 = num1.replace(/\.{2,}/g, '.'); // 只保留第一个. 清除多余的
  num1 = num1.replace('.', '$#$').replace(/\./g, '').replace('$#$', '.');
  num1 = num1.replace(/^(\-)*(\d+)\.(\d{2}).*$/, '$1$2.$3'); // 只能输入2个小数
  return num1;
}

/**
 * Android封装唤起照片选择
 * @param capture CAMERA 相机；ALBUM 相册
 */
export function imgUpload(capture?: string) {
  if (config.isKhtAPP && config.isAndroidXZ) {
    const paiZhaoXC = JSON.stringify({
      isShowCamera: true,
      isShowAlbum: true,
      cameraText: '手机拍照',
      albumText: '从手机相册选择',
      location: 'BOTTOM',
      directOpen: capture,
    });
    kht.getImgString(paiZhaoXC);
  }
}
